#
# This script provides a simple wrapper to create a CQP subcorpus by performing a query.
# The subcorpus name is returned, and as a side effect, the concordance is shown.
#

# Make sure rcqp is loaded.
require(rcqp)

cqp <- function(acorpus, aquery)
{

  # Set left/right context default if the caller has not defined the variables lc and rc.
  if (!exists("lc")) lc <- 20
  if (!exists("rc")) rc <- 20

  # Use the high-level rcqp corpus objects, define the corpus.
  c <- corpus(acorpus)

  # Perform a query, creating a subcorpus R object.
  tt <- proc.time()
  sc <- subcorpus(c, aquery)
  tt <- proc.time() - tt
  tt <- tt[3]

  # Report basic statistics for the query.
  s <- size(sc)
  cat("Query:      ", aquery, "\n")
  cat("Corpus:     ", cqi_full_name(acorpus), "\n")
  cat("Matches:    ", s, "\n")
  cat("Time taken: ", tt, "\n")

  # This creates an rcqp KWIC object, which can be easily manipulated.
  k <- cqp_kwic(sc, right.context=rc, left.context=lc)

  # A simple loop to display 20 results of the KWIC at a time .
  froms <- seq(0, s, by=20)
  for (from in froms)
  {
    to <- from+19
    if (to >= s) to <- s-1
    
    cat("\nPress [ENTER] to see matches", from, "to", to, "or q + [ENTER] to quit.\n")
    l <- readline()
    if (l == "q") break

    # The generic R print() function is overloaded in rcqp to handle KWIC objects.
    print(k, from=from, to=to)
  }

  # This extracts the the (obscure/random) subcorpus name from the cubcorpus object with attr().
  # the paste() call attaches the corpus name to its left for convenience.
  paste(acorpus, ':', attr(sc, "cqp_subcorpus.name"), sep="")
}


# This is a wrapper around cqp(), with our demo corpus as default.
uk12 <- function(aquery) { cqp("UKCOW2012D", aquery) }


cat("\nYou have loaded the simple rcqp wrapper for the HPSG pre-conf tutorial.\n\n")